@@ -232,6 +232,41 @@ class ObjectTest(unittest.TestCase):
         self.assertEquals(u'ntoll', user.username)
         self.assertEquals(u'ntoll', user.name)
 
+class TagValueTest(unittest.TestCase):
+
+    def setUp(self):
+        self.fluid = sandbox_fluid()
+        n = Namespace(u'test')
+        for name in (u'fomtest', u'fomtest2'):
+            try:
+                n.create_tag(u'fomtest', u'%s description' % name, False)
+            except Fluid412Error:
+                pass
+
+    def testDefaultType(self):
+        """
+        Make sure that the content-type is set to the appropriate mime-type
+        should the defaultType argument be specified
+        """
+        class fomtest(Object):
+            ft = tag_value('test/fomtest')
+            ft2 = tag_value('test/fomtest2', 'text/html')
+
+        obj = fomtest(about="A test object")
+        # default behaviour
+        obj.ft = 1
+        obj.ft2 = '<html><body>Hello, World</body></html>'
+        ft_result = obj.get('test/fomtest')
+        ft2_result = obj.get('test/fomtest2')
+        self.assertEquals('application/vnd.fluiddb.value+json', ft_result[1])
+        self.assertEquals('text/html', ft2_result[1])
+        # But we *can* override the mime if we use the object's set method
+        obj.set('test/fomtest2', 'foo', None)
+        self.assertEquals('foo', obj.ft2)
+        ft2_result = obj.get('test/fomtest2')
+        self.assertEquals('application/vnd.fluiddb.value+json', ft2_result[1])
+
+
 class TagTest(unittest.TestCase):
 
     def setUp(self):
